package org.springblade.mcp.utils;

import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import org.springblade.core.tool.utils.StringPool;
import org.springframework.util.DigestUtils;

import cn.hutool.core.util.StrUtil;

/**
 * 
 *
 * @author aokunsang
 */
public class DigestUtil extends org.springframework.util.DigestUtils {
	
	private static final char[] HEX_CODE = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};

	/**
	 * encode Hex
	 *
	 * @param bytes Data to Hex
	 * @return bytes as a hex string
	 */
	public static String encodeHex(byte[] bytes) {
		StringBuilder r = new StringBuilder(bytes.length * 2);
		for (byte b : bytes) {
			r.append(HEX_CODE[(b >> 4) & 0xF]);
			r.append(HEX_CODE[(b & 0xF)]);
		}
		return r.toString();
	}
	
	/**
	 * digest Hex
	 *
	 * @param algorithm 算法
	 * @param bytes     Data to digest
	 * @return digest as a hex string
	 */
	public static String digestHex(String algorithm, byte[] bytes) {
		try {
			MessageDigest md = MessageDigest.getInstance(algorithm);
			return encodeHex(md.digest(bytes));
		} catch (NoSuchAlgorithmException e) {
			throw new RuntimeException(e);
		}
	}
	
	/**
	 * sha1Hex
	 *
	 * @param bytes Data to digest
	 * @return digest as a hex string
	 */
	public static String sha1Hex(final byte[] bytes) {
		return DigestUtil.digestHex("SHA-1", bytes);
	}
	
	/**
	 * sha1Hex
	 *
	 * @param data Data to digest
	 * @return digest as a hex string
	 */
	public static String sha1Hex(String data) {
		return DigestUtil.sha1Hex(data.getBytes(StandardCharsets.UTF_8));
	}
	
	/**
	 * 自定义加密 将前端传递的密码再次加密
	 *
	 * @param data 数据
	 * @return {String}
	 */
	public static String hex(String data) {
		if (StrUtil.isBlank(data)) {
			return StringPool.EMPTY;
		}
		return sha1Hex(data);
	}

	/**
	 * 用户密码加密规则 先MD5再SHA1
	 *
	 * @param data 数据
	 * @return {String}
	 */
	public static String encrypt(String data) {
		if (StrUtil.isBlank(data)) {
			return StringPool.EMPTY;
		}
		return sha1Hex(md5Hex(data));
	}
	

	/**
	 * Calculates the MD5 digest and returns the value as a 32 character hex string.
	 *
	 * @param data Data to digest
	 * @return MD5 digest as a hex string
	 */
	public static String md5Hex(final String data) {
		return DigestUtils.md5DigestAsHex(data.getBytes(StandardCharsets.UTF_8));
	}

}
