package org.springblade.mcp.utils;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.springblade.core.constant.TokenConstant;
import org.springblade.core.secure.TokenInfo;
import org.springblade.core.secure.utils.SecureUtil;
import org.springblade.core.tool.support.Kv;
import org.springblade.core.tool.utils.Func;
import org.springblade.mcp.entity.McpUser;

/**
 * 认证工具类
 *
 * @author Chill
 */
public class TokenUtil {

	public static Kv createAuthInfo(McpUser mcpUser) {
		Kv authInfo = Kv.create();
		//设置jwt参数
		Map<String, Object> param = new HashMap<>(16);
		param.put(TokenConstant.TOKEN_TYPE, TokenConstant.ACCESS_TOKEN);
		//--->>以上需要设置值
		param.put(TokenConstant.USER_ID, Func.toStr(mcpUser.getUserId()));
		param.put(TokenConstant.ACCOUNT, mcpUser.getUserName());
		param.put(TokenConstant.USER_NAME, mcpUser.getUserName());
		param.put(TokenConstant.NICK_NAME, mcpUser.getNickName());
		//---->>以上需要设置值
		
		//拼装accessToken
		try {
			TokenInfo accessToken = SecureUtil.createJWT(param, "audience", "issuser", TokenConstant.ACCESS_TOKEN);
			//返回accessToken
			return authInfo.set(TokenConstant.USER_ID, Func.toStr(mcpUser.getUserId()))
				.set(TokenConstant.ACCESS_TOKEN, accessToken.getToken())
				.set(TokenConstant.REFRESH_TOKEN, createRefreshToken(Func.toStr(mcpUser.getUserId())).getToken())
				.set(TokenConstant.TOKEN_TYPE, TokenConstant.BEARER)
				.set(TokenConstant.EXPIRES_IN, accessToken.getExpire())
				.set(TokenConstant.ACCOUNT, mcpUser.getUserName())
				.set(TokenConstant.USER_NAME, mcpUser.getUserName())
				.set(TokenConstant.NICK_NAME, mcpUser.getNickName());
		} catch (Exception ex) {
			return authInfo.set("error_code", HttpServletResponse.SC_UNAUTHORIZED).set("error_msg", ex.getMessage());
		}
	}
	
	/**
	 * 创建refreshToken
	 *
	 * @param userInfo 用户信息
	 * @return refreshToken
	 */
	private static TokenInfo createRefreshToken(String userId) {
		Map<String, Object> param = new HashMap<>(16);
		param.put(TokenConstant.TOKEN_TYPE, TokenConstant.REFRESH_TOKEN);
		param.put(TokenConstant.USER_ID, userId);
		return SecureUtil.createJWT(param, "audience", "issuser", TokenConstant.REFRESH_TOKEN);
	}
}
